Tutorials
===================================

These tutorials walk through how to use Covasim. If you want to explore them interactively, start a Jupyter environment in this folder (``docs/tutorials``). You can use either ``jupyter lab`` or ``jupyter notebook`` to run these tutorials.

.. toctree::
    :maxdepth: 1

    t1
    t2
    t3
    t4
    t5
    t6
    t7
    t8
    t9
